@@ -8,9 +8,9 @@
 #if !defined(FRAMELIB_DEFINED)
 #define FRAMELIB_DEFINED
 
-#define FRAMELIB_VERSION  8.20
-#define FR_VERS           8020
-#define FR_MINOR_VERSION    20
+#define FRAMELIB_VERSION  8.30
+#define FR_VERS           8030
+#define FR_MINOR_VERSION    30
 #define FRPI              3.14159265358979
 #define FRTWOPI           6.2831853071795864769
 
@@ -72,7 +72,7 @@ typedef enum {FR_OK,
 #define FRMAPMAXINSTANCE 500
 /*--------------------------- time define ----------------------------------*/
 #define FRGPSOFF 315964800
-#define FRGPSDELTA  16
+#define FRGPSDELTA  17
 #define FRGPSTAI    19  /* in case of change, update the function FrGPS2UTC */
 #define FRGPSLEAPS (FRGPSTAI+FRGPSDELTA)
 /* Just some rules about time .......                                       */
@@ -80,13 +80,14 @@ typedef enum {FR_OK,
 /* the C function time origin is Jan 1 00:00:00 1970 (no leap seconds)      */
 /*       (C time - GPS time = 3600*24*3567 = 315964800 seconds)             */
 /*  TAI is ahead of GPS by 19 seconds                                       */
-/*  TAI is ahead of UTC by 32 seconds (July 2001)                           */
+/*  TAI is ahead of UTC by 36 seconds (from July 2015)                      */
  /*---- GPS time = UTC - 3600*24*3657 + delta ------------------------------*/
 /*from 1997 01 Jul, UTC:   delta = +12s                                     */
 /*from 1999 01 Jan, UTC:   delta = +13s                                     */
 /*from 2006 01 Jan, UTC:   delta = +14s                                     */
 /*from 2009 01 Jan, UTC:   delta = +15s                                     */
 /*from 2012 01 Jul, UTC:   delta = +16s                                     */
+/*from 2015 01 Jul, UTC:   delta = +17s                                     */
 /*See http://tycho.usno.navy.mil/time.html or http://hpiers.obspm.fr/eop-pc */
 /* See also the function FrGetLeapS                                         */
 /*--------------------------------------------------------------------------*/
@@ -278,10 +279,11 @@ void    FrameUntagSimEvt(FrameH *frame);
 void    FrameUntagStat (FrameH *frame);
 void    FrameUntagSum  (FrameH *frame);
 int     FrameWrite     (FrameH *frame, FrFile *oFile);
-FRLONG  FrameWriteToBuf(FrameH *frame, int comp, char *buf, FRLONG nBytes);
+FRLONG  FrameWriteToBuf(FrameH *frame, int comp, char *buf, FRLONG nBytes,
+                        int computeChecksum);
 /*---------------------------------------------------------------------------*/
 FrameH *FrameHCopy(FrameH *in);
-FrSH   *FrameHDef();    
+FrSH   *FrameHDef(void);    
 FrameH *FrameHRead (FrFile *iFile);
 FrameH *FrameHReadN(FrFile *iFile,int rNumber, int fNumber);
 FrameH *FrameHReadT(FrFile *iFile,double gtime);
@@ -316,7 +318,7 @@ struct FrAdcData {               /* hold ADC data (or image)                 */
 
 FrAdcData *FrAdcDataCopy(FrAdcData *adc, FrameH *frame);
 int        FrAdcDataDecimate(FrAdcData *adc, int nGroup);
-FrSH      *FrAdcDataDef();
+FrSH      *FrAdcDataDef(void);
 void       FrAdcDataDump(FrAdcData *adc, FILE *fp, int debugLvl);
 FrAdcData *FrAdcDataFind (FrameH *frame, char *adcName); 
 void       FrAdcDataFree(FrAdcData *adc);
@@ -377,7 +379,7 @@ struct FrDetector {
 };
 
 int         FrDetectorAddStatData(FrDetector* detector, FrStatData *stat);
-FrSH       *FrDetectorDef();    
+FrSH       *FrDetectorDef(void);    
 void        FrDetectorDump(FrDetector *detector, FILE *fp, int debugLvl);
 FrDetector *FrDetectorMerge(FrDetector *det1, FrDetector *det2);
 FrDetector *FrDetectorNew(char *name);
@@ -408,7 +410,7 @@ struct FrEndOfFrame {            /* End of Frame Marker                      */
   unsigned int chkSum;           /* checkSum value                           */
                                  /* ------------- end_of_SIO parameters ---- */
 };
-FrSH *FrEndOfFrameDef();    
+FrSH *FrEndOfFrameDef(void);    
 void  FrEndOfFrameRead (FrFile *iFile);
 void  FrEndOfFrameWrite(FrameH *frameH, FrFile *oFile);
 /*---------------------------------------------------------------------------*/
@@ -421,7 +423,7 @@ struct FrEndOfFile {             /* End of File Marker                       */
   FRULONG       seekTOC;         /* seek for the TOC                         */
                                  /* ------------- end_of_SIO parameters ---- */
 };
-FrSH *FrEndOfFileDef();
+FrSH *FrEndOfFileDef(void);
 void  FrEndOfFileRead (FrFile *iFile);
 void  FrEndOfFileWrite(FrFile *oFile);
 
@@ -454,7 +456,7 @@ int      FrEventAddVect (FrEvent *event,  FrVect *vect, char* newName);
 int      FrEventAddVectF(FrEvent *event,  FrVect *vect, char* newName);
 
 FrEvent *FrEventCopy(FrEvent *event);
-FrSH    *FrEventDef();
+FrSH    *FrEventDef(void);
 void     FrEventDump(FrEvent *event, FILE *fp, int debugLvl);
 FrEvent* FrEventFind(FrameH *frameH, char *name, FrEvent *last);
 FrVect*  FrEventFindVect(FrEvent *event, char *vectName);
@@ -635,6 +637,8 @@ FrVect *FrFileIGetVType(FrFile *iFile, char *name, double tStart, double len,
 double FrFileIGetNextEventTime(FrFile *iFile, char *name, double tStart,
                                   double amplitudeMin);
 int     FrFileIGoToNextRecord(FrFile *iFile);
+FrFile* FrFileIInMemoryNew();
+double  FrFileIInMemoryAddBuffer(FrFile* file, char* buf, int size, double tSpan);
 FrFile *FrFileINew  (char *fileName);
 FrFile *FrFileINewFd(FrIO *frfd);
 int     FrFileINext  (FrFile *iFile,double tStart,double len,
@@ -644,6 +648,7 @@ void    FrFileIOpen  (FrFile *file);
 FRLONG  FrFileIOSet(FrFile *iFile, FRLONG offset);
 FRLONG  FrFileIOSetFromEnd(FrFile *iFile, FRLONG offset);
 FRLONG  FrFileIOSetFromCur(FrFile *iFile, FRLONG offset);
+FRLONG  FrFileIOTell(FrFile *iFile);
 FrFile *FrFileIRewind(FrFile *iFile);
 void    FrFileISegListMatch(FrFile *iFile);
 int     FrFileISetTime(FrFile *iFile, double gtime);
@@ -654,7 +659,7 @@ double  FrFileITLastEvt  (FrFile *iFile);
 double  FrFileITNextFrame(FrFile *iFile,double gtime);
 double  FrFileITStart    (FrFile *iFile);
 
-int     FrFileOEnd(FrFile *file);
+FRLONG  FrFileOEnd(FrFile *file);
 FrFile *FrFileONew (char *fileName, int compress);
 FrFile *FrFileONewH(char *fileName, int compress, char *program);
 FrFile *FrFileONewFd   (FrIO *frfd, int compress);
@@ -677,11 +682,13 @@ struct FrFileH{                  /* header for each file                     */
   double length;                 /* time length for this file                */
   double tFirstEvt;              /* GPS time for earliest event in file      */
   double tLastEvt;               /* GPS time for the latest event in file    */
+  char  *iMBuffer;               /* buffer if the file is written in memory  */
+  int    iMBSize;                /* number of bytes of iMBuffer              */
   FrFileH* next;                 /* next FrFileH in the linked list          */
 };
 
 int    FrGetLeapS(unsigned int gps);
-double FrGetCurrentGPS ();
+double FrGetCurrentGPS (void);
 
 /*---------------------------------------------------------------------------*/
 struct FrHistory {               /* Describes data history info.             */
@@ -695,7 +702,7 @@ struct FrHistory {               /* Describes data history info.             */
 
 FrHistory *FrHistoryAdd(FrameH *frame, char *comment);
 FrHistory *FrHistoryCopy(FrHistory *historyIn);
-FrSH      *FrHistoryDef();    
+FrSH      *FrHistoryDef(void);    
 void       FrHistoryFree(FrHistory *history);
 FrHistory *FrHistoryNew(char *name, unsigned int mytime, char *comment);
 void       FrHistoryRead(FrFile *iFile);
@@ -725,7 +732,7 @@ struct FrMsg {                   /* hold  message      information           */
 }; 
 FrMsg *FrMsgAdd(FrameH *frame, char *alarm, char *message, 
                                unsigned int severity);
-FrSH  *FrMsgDef();
+FrSH  *FrMsgDef(void);
 void   FrMsgDump(FrMsg *msg,FILE *fp, int debugLvl);
 FrMsg *FrMsgFind(FrameH *frame, char *alarm, FrMsg *msg);
 void   FrMsgFree(FrMsg *msg);
@@ -737,7 +744,7 @@ struct FrObject {                /* prototype of FrameLib structure          */
   char *name;                    /* name for this element                    */
 }; 
 
-FrSH *FrObjectDef();
+FrSH *FrObjectDef(void);
 /*---------------------------------------------------------------------------*/
 struct FrProcData {              /* process and reconstructed data           */
   FrSH *classe;                  /* class information (internal structure)   */
@@ -772,7 +779,7 @@ FrHistory  *FrProcDataAddHistory(FrProcData *proc,char *comment,int nPrev,...);
 FrProcData *FrProcDataAddParam  (FrProcData *proc,char *name, double value);
 void        FrProcDataAttachVect(FrProcData *proc, FrVect *vect);
   FrProcData *FrProcDataCopy(FrProcData *procIn, FrameH* frame);
-FrSH       *FrProcDataDef();
+FrSH       *FrProcDataDef(void);
 void        FrProcDataDump(FrProcData *proc, FILE *fp,  int debugLvl);
 FrProcData *FrProcDataFind (FrameH *frame, char *name);
 FrVect*     FrProcDataFindVect(FrProcData *proc, char *name);
@@ -802,7 +809,7 @@ struct FrRawData {               /* Hold raw data                            */
   FrMsg     *logMsgOld;          /* used by the tag/untag function           */
 };
 
-FrSH      *FrRawDataDef();    
+FrSH      *FrRawDataDef(void);    
 void       FrRawDataDump(FrRawData *rawData, FILE *fp, int debugLvl);
 void       FrRawDataFree(FrRawData *rawData);
 FrRawData *FrRawDataNew(FrameH *frame);
@@ -820,7 +827,7 @@ struct FrSE {                    /* hold structure information(one per line) */
                                  /* ------------ end_of_SIO parameters ------*/
   FrSE *next;                    /* next struct E                            */
 };
-FrSH *FrSEDef();
+FrSH *FrSEDef(void);
 void  FrSENew(FrSH *structH, char *type, char *name, char *comment);
 void  FrSERead(FrFile *iFile);
 void  FrSEWrite(FrSE *structE, FrFile *oFile);
@@ -864,7 +871,7 @@ struct FrSerData {               /* slow monitoring station data             */
   char *data;                    /* pointer to the data block                */
 };
 
-FrSH      *FrSerDataDef();  
+FrSH      *FrSerDataDef(void);  
 void       FrSerDataDump(FrSerData *serData, FILE *fp, int debugLvl);
 FrSerData *FrSerDataFind(FrameH *frameH,char *smsName, FrSerData *sms);
 void       FrSerDataFree(FrSerData *smsData);
@@ -887,12 +894,12 @@ struct FrSH {                    /* hold info for this type of struct        */
   int    nInstances;             /* total number of instances for this struct*/
                                  /* ------------ end_of_SIO parameters ------*/
   FrSE *firstE;                  /* first structure element                  */
-  void (*objRead)();             /* function to read the object on file      */
+  void (*objRead)(FrFile *iFile);/* function to read the object on file      */
   int nSE;                       /* number of element for this structure     */
   FrSH *shRef;                   /* reference SH struct (used for in. file)  */
 };
 
-FrSH *FrSHDef();
+FrSH *FrSHDef(void);
 void  FrSHMatch(FrFile *iFile);
 FrSH *FrSHNew(char *name, char *comment);
 void  FrSHRead(FrFile *iFile);
@@ -916,7 +923,7 @@ struct FrSimData {               /* hold Simulated data                      */
                                  /* ------ end_of_SIO parameters ------------*/
 }; 
 
-FrSH      *FrSimDataDef();    
+FrSH      *FrSimDataDef(void);    
 void       FrSimDataDump(FrSimData *simData, FILE *fp, int debugLvl);
 FrSimData *FrSimDataFind (FrameH *frame, char *name);
 void       FrSimDataFree(FrSimData *simData);
@@ -952,7 +959,7 @@ int         FrSimEventAddVect (FrSimEvent *event,  FrVect *vect, char* newName);
 int         FrSimEventAddVectF(FrSimEvent *event,  FrVect *vect, char* newName);
 
 FrSimEvent *FrSimEventCopy(FrSimEvent *event);
-FrSH       *FrSimEventDef();
+FrSH       *FrSimEventDef(void);
 void        FrSimEventDump(FrSimEvent *simEvent,FILE *fp, int debugLvl);
 FrSimEvent *FrSimEventFind(FrameH *frameH, char *name, FrSimEvent *last);
 FrVect*     FrSimEventFindVect  (FrSimEvent *event, char *vectName);
@@ -1008,7 +1015,7 @@ void        FrStatDataAddVect(FrStatData *stat, FrVect *vect);
 void        FrStatDataChkT(FrStatData **root, 
                        unsigned int timeStart, unsigned int timeEnd);
 FrStatData *FrStatDataCopy(FrStatData *sData, FrDetector *detector);
-FrSH       *FrStatDataDef();    
+FrSH       *FrStatDataDef(void);    
 void        FrStatDataDump(FrStatData *sData, FILE *fp, int debugLvl);
 FrStatData *FrStatDataFind(FrDetector *detector, char *name,
                        unsigned int timeNow);
@@ -1037,7 +1044,7 @@ struct FrSummary {
   unsigned int GTimeN;           /* FrSummary time (GPS nano second)         */
                                  /* -------- end_of_SIO parameters ----------*/
 }; 
-FrSH      *FrSummaryDef();
+FrSH      *FrSummaryDef(void);
 void       FrSummaryDump(FrSummary *summary, FILE *fp, int debugLvl);
 FrSummary *FrSummaryFind (FrameH *frame, char *name);
 void       FrSummaryFree(FrSummary *summary);
@@ -1060,7 +1067,7 @@ struct FrTable {
 };
 void     FrTableCompress(FrTable *table, int compType, int gzipLevel);
 FrTable *FrTableCopy    (FrTable *table);
-FrSH    *FrTableDef();
+FrSH    *FrTableDef(void);
 void     FrTableDump  (FrTable *table, FILE *fp, int debugLvl);
 void     FrTableExpand(FrTable *table);
 FrVect*  FrTableGetCol(FrTable *table, char *colName);
@@ -1120,7 +1127,7 @@ struct FrTOC {                   /* File Table Of Content                    */
   int maxFrame;
   FRLONG position;
 };
-FrSH  *FrTOCDef();
+FrSH  *FrTOCDef(void);
 void   FrTOCDump(FrTOC *toc, FILE *fp, int debugLvl, char *tag);
 void   FrTOCFFLBuild(FrFile *iFile);
 void   FrTOCFree(FrTOC *toc);
@@ -1231,11 +1238,12 @@ FrVect *FrVectCopyToD  (FrVect *vect, double scale, char *newName);
 FrVect *FrVectCopyToF  (FrVect *vect, double scale, char *newName);
 FrVect *FrVectCopyToI  (FrVect *vect, double scale, char *newName);
 FrVect *FrVectCopyToS  (FrVect *vect, double scale, char *newName);
+FrVect *FrVectCopyToType(FrVect *vect, double scale, char *newName, int type);
 
 FrVect *FrVectDecimate(FrVect *vect, int nGroup, FrVect *outVect);
 void    FrVectDecimateMax(FrVect *vect, int nGroup);
 void    FrVectDecimateMin(FrVect *vect, int nGroup);
-FrSH   *FrVectDef();    
+FrSH   *FrVectDef(void);    
 char   *FrVectDiff   (FrVect *vect);
 void    FrVectDump   (FrVect *vect, FILE *fp, int debugLvl);
 void    FrVectExpand (FrVect *vect);
@@ -1252,6 +1260,7 @@ int     FrVectFindQ  (FrVect *vect, char *name);
 int     FrVectFixNAN(FrVect *vect);
 void    FrVectFixVirgoImage(FrVect *vect);
 void    FrVectFree   (FrVect *vect);
+#define FRVECTFREE(a) FrVectFree(a); a = NULL;
 
 FRLONG  FrVectGetIndex  (FrVect *vect, double x);
 FRLONG  FrVectGetTotSize(FrVect *vect);
@@ -1267,8 +1276,10 @@ void    FrVectIsValidFillAux(FrVect *vect);
 int     FrVectIsValidStrict(FrVect *vect);
 FrVect* FrVectLoad(char *fileName);
 void    FrVectMap    (FrVect *vect);
+double  FrVectMax    (FrVect *vect);
 FrVect *FrVectMergeT (FrVect **vectIn, int nVect);
 double  FrVectMean   (FrVect *vect);
+double  FrVectMin    (FrVect *vect);
 int     FrVectMinMax (FrVect *vect, double *min, double *max);
 FrVect *FrVectNew  (int type, int nDim, ...);
 FrVect *FrVectNewL (int type, int nDim, ...);
@@ -1314,22 +1325,22 @@ int     FrVectZoomOut(FrVect *vect);
 /*  General functions                                                       */
 /*--------------------------------------------------------------------------*/
 FILE *FrLibIni(char *outFile, FILE *fOut, int dbglvl);
-void  FrLibShortIni();
+void  FrLibShortIni(void);
 void  FrLibSetLvl(int dbglvl);
 void  FrLibSetFlipPrefix(char *prefix);
 void  FrLibSetVersion(int formatVersion);
 float FrLibVersion(FILE *fOut);
-char *FrLibVersionF();
+char *FrLibVersionF(void);
 /*--------------------------------------------------------------------------*/
 char *FrError(int level, char *subroutine, char *message);
-char *FrErrorGetHistory();
+char *FrErrorGetHistory(void);
 void  FrErrorDefHandler(int level, char *lastMessage);
 void  FrErrorSetHandler(void  (*handler)(int, char *));
 /*--------------------------------------------------------------------------*/
 unsigned int FrChkSum(FRSCHAR *buf, int nBytes, int start);
 void FrCksumGnu (char *buf, FRLONG nBytes, unsigned int *crc);
 /*---------------------------------------------------------------------------*/
-FrSH *FrDicAddS(char *type, void (*funRead)());         
+FrSH *FrDicAddS(char *type, void (*funRead)(void));         
 int   FrDicAssignId(struct FrFile *file, unsigned short type, void *address);
 int   FrDicGetId   (struct FrFile *file, unsigned short type, void *address);
 void  FrDicIni     (struct FrFile *file);
